<?php

namespace Restaurant\Feedback\Policies;

use Litepie\User\Contracts\UserPolicy;
use Restaurant\Feedback\Models\FeedBack;

class FeedBackPolicy
{

    /**
     * Determine if the given user can view the feed_back.
     *
     * @param UserPolicy $user
     * @param FeedBack $feed_back
     *
     * @return bool
     */
    public function view(UserPolicy $user, FeedBack $feed_back)
    {
        if ($user->canDo('feedback.feed_back.view') && $user->isAdmin()) {
            return true;
        }

        return $feed_back->user_id == user_id() && $feed_back->user_type == user_type();
    }

    /**
     * Determine if the given user can create a feed_back.
     *
     * @param UserPolicy $user
     * @param FeedBack $feed_back
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('feedback.feed_back.create');
    }

    /**
     * Determine if the given user can update the given feed_back.
     *
     * @param UserPolicy $user
     * @param FeedBack $feed_back
     *
     * @return bool
     */
    public function update(UserPolicy $user, FeedBack $feed_back)
    {
        if ($user->canDo('feedback.feed_back.edit') && $user->isAdmin()) {
            return true;
        }

        return $feed_back->user_id == user_id() && $feed_back->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given feed_back.
     *
     * @param UserPolicy $user
     * @param FeedBack $feed_back
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, FeedBack $feed_back)
    {
        return $feed_back->user_id == user_id() && $feed_back->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given feed_back.
     *
     * @param UserPolicy $user
     * @param FeedBack $feed_back
     *
     * @return bool
     */
    public function verify(UserPolicy $user, FeedBack $feed_back)
    {
        if ($user->canDo('feedback.feed_back.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given feed_back.
     *
     * @param UserPolicy $user
     * @param FeedBack $feed_back
     *
     * @return bool
     */
    public function approve(UserPolicy $user, FeedBack $feed_back)
    {
        if ($user->canDo('feedback.feed_back.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
